# Generated by Django 3.1.6 on 2021-02-28 20:19

from django.db import migrations, models
import edc_model.models.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0009_auto_20210228_2107'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dminitialreview',
            name='glucose',
        ),
        migrations.RemoveField(
            model_name='dminitialreview',
            name='glucose_date',
        ),
        migrations.RemoveField(
            model_name='dminitialreview',
            name='glucose_fasted',
        ),
        migrations.RemoveField(
            model_name='dminitialreview',
            name='glucose_quantifier',
        ),
        migrations.RemoveField(
            model_name='dminitialreview',
            name='glucose_units',
        ),
        migrations.RemoveField(
            model_name='historicaldminitialreview',
            name='glucose',
        ),
        migrations.RemoveField(
            model_name='historicaldminitialreview',
            name='glucose_date',
        ),
        migrations.RemoveField(
            model_name='historicaldminitialreview',
            name='glucose_fasted',
        ),
        migrations.RemoveField(
            model_name='historicaldminitialreview',
            name='glucose_quantifier',
        ),
        migrations.RemoveField(
            model_name='historicaldminitialreview',
            name='glucose_units',
        ),
        migrations.AlterField(
            model_name='dminitialreview',
            name='glucose_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='If yes, complete the Glucose result form.', max_length=15, verbose_name='Has the patient had their glucose measured in the last few months?'),
        ),
        migrations.AlterField(
            model_name='dminitialreview',
            name='managed_by',
            field=models.CharField(choices=[('insulin', 'Insulin injections'), ('drugs', 'Oral drugs'), ('diet_lifestyle', 'Diet and lifestyle alone')], default='N/A', help_text='If insulin or oral drugs, diet and lifestyle is assumed.', max_length=25, verbose_name="How is the patient's diabetes managed?"),
        ),
        migrations.AlterField(
            model_name='historicaldminitialreview',
            name='glucose_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], help_text='If yes, complete the Glucose result form.', max_length=15, verbose_name='Has the patient had their glucose measured in the last few months?'),
        ),
        migrations.AlterField(
            model_name='historicaldminitialreview',
            name='managed_by',
            field=models.CharField(choices=[('insulin', 'Insulin injections'), ('drugs', 'Oral drugs'), ('diet_lifestyle', 'Diet and lifestyle alone')], default='N/A', help_text='If insulin or oral drugs, diet and lifestyle is assumed.', max_length=25, verbose_name="How is the patient's diabetes managed?"),
        ),
        migrations.AlterField(
            model_name='historicalhivinitialreview',
            name='arv_initiation_actual_date',
            field=models.DateField(blank=True, help_text='Calculated based on response to `arv_initiation_ago`', null=True, validators=[edc_model.models.validators.date.date_not_future], verbose_name='Date started antiretroviral therapy (ART)'),
        ),
        migrations.AlterField(
            model_name='hivinitialreview',
            name='arv_initiation_actual_date',
            field=models.DateField(blank=True, help_text='Calculated based on response to `arv_initiation_ago`', null=True, validators=[edc_model.models.validators.date.date_not_future], verbose_name='Date started antiretroviral therapy (ART)'),
        ),
    ]
