# Generated by Django 3.0.9 on 2020-12-04 20:39

import django_crypto_fields.fields.encrypted_char_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0014_auto_20201204_1949"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="best_tel",
            field=models.CharField(
                choices=[
                    ("tel_1", "Tel/Mobile(1)"),
                    ("tel_2", "Tel/Mobile(2)"),
                    ("tel_3", "Tel/Mobile(3)"),
                ],
                max_length=15,
                null=True,
                verbose_name="Best Telephone / Mobile",
            ),
        ),
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="tel_one",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Tel/Mobile(1)",
            ),
        ),
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="tel_three",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Tel/Mobile(3)",
            ),
        ),
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="tel_two",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Tel/Mobile(2)",
            ),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="best_tel",
            field=models.CharField(
                choices=[
                    ("tel_1", "Tel/Mobile(1)"),
                    ("tel_2", "Tel/Mobile(2)"),
                    ("tel_3", "Tel/Mobile(3)"),
                ],
                max_length=15,
                null=True,
                verbose_name="Best Telephone / Mobile",
            ),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="tel_one",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Tel/Mobile(1)",
            ),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="tel_three",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Tel/Mobile(3)",
            ),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="tel_two",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Tel/Mobile(2)",
            ),
        ),
    ]
