# Generated by Django 3.0.9 on 2020-12-05 01:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0017_auto_20201205_0401"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="next_appt_date",
            field=models.DateField(null=True, verbose_name="Next Appt."),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="next_appt_date",
            field=models.DateField(null=True, verbose_name="Next Appt."),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregistercontact",
            name="call_again",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Call again?",
            ),
        ),
        migrations.AlterField(
            model_name="moccaregistercontact",
            name="call_again",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Call again?",
            ),
        ),
    ]
