# Generated by Django 3.1.6 on 2021-02-28 17:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_lists', '0003_auto_20210225_0728'),
    ]

    operations = [
        migrations.CreateModel(
            name='DiagnosisLocations',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, help_text='This is the stored value, required', max_length=250, unique=True, verbose_name='Stored value')),
                ('display_name', models.CharField(db_index=True, help_text='(suggest 40 characters max.)', max_length=250, unique=True, verbose_name='Name')),
                ('display_index', models.IntegerField(db_index=True, default=0, help_text='Index to control display order if not alphabetical, not required', verbose_name='display index')),
                ('field_name', models.CharField(blank=True, editable=False, help_text='Not required', max_length=25, null=True)),
                ('version', models.CharField(default='1.0', editable=False, max_length=35)),
            ],
            options={
                'verbose_name': 'Diagnosis Locations',
                'verbose_name_plural': 'Diagnosis Locations',
                'ordering': ['display_index', 'display_name'],
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'),
            },
        ),
        migrations.AddIndex(
            model_name='diagnosislocations',
            index=models.Index(fields=['id', 'display_name', 'display_index'], name='mocca_lists_id_a18628_idx'),
        ),
    ]
