# Generated by Django 3.0.9 on 2020-12-03 13:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0002_auto_20201203_0338"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmoccaregister",
            name="gender",
            field=models.CharField(
                choices=[("M", "Male"), ("F", "Female")], max_length=10, null=True
            ),
        ),
        migrations.AlterField(
            model_name="moccaregister",
            name="gender",
            field=models.CharField(
                choices=[("M", "Male"), ("F", "Female")], max_length=10, null=True
            ),
        ),
    ]
