# Generated by Django 3.1.6 on 2021-03-02 04:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0015_auto_20210301_0745'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='drugsupplydm',
            name='drug',
        ),
        migrations.RemoveField(
            model_name='drugsupplydm',
            name='drug_refill',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhiv',
            name='drug',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhiv',
            name='drug_refill',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhtn',
            name='drug',
        ),
        migrations.RemoveField(
            model_name='drugsupplyhtn',
            name='drug_refill',
        ),
        migrations.DeleteModel(
            name='DrugSupplyChol',
        ),
        migrations.DeleteModel(
            name='DrugSupplyDm',
        ),
        migrations.DeleteModel(
            name='DrugSupplyHiv',
        ),
        migrations.DeleteModel(
            name='DrugSupplyHtn',
        ),
    ]
