# Generated by Django 3.0.9 on 2020-12-15 12:52

import edc_sites.models
from django.db import migrations

import mocca_screening.models.subject_refusal_screening


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0006_auto_20201215_1543"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectrefusalscreening",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", mocca_screening.models.subject_refusal_screening.Manager()),
            ],
        ),
    ]
