# Generated by Django 3.0.9 on 2020-12-04 03:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0012_auto_20201204_0352"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="moccaregister",
            name="unique_first_name__last_name",
        ),
    ]
