# Generated by Django 3.0.9 on 2020-12-03 23:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0004_auto_20201203_1757"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="contact_attempts",
            field=models.IntegerField(default=0),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="contact_attempts",
            field=models.IntegerField(default=0),
        ),
    ]
