# Generated by Django 3.1.6 on 2021-02-25 03:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0010_auto_20201217_0626'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='mocca_study_identifier',
            field=models.CharField(db_index=True, help_text='Format must match original identifier. e.g. 12-3456 for UG, 123456 for TZ', max_length=25, verbose_name='MOCCA (original) study identifier'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectscreening',
            name='subject_identifier',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='mocca_study_identifier',
            field=models.CharField(help_text='Format must match original identifier. e.g. 12-3456 for UG, 123456 for TZ', max_length=25, unique=True, verbose_name='MOCCA (original) study identifier'),
        ),
        migrations.AlterField(
            model_name='subjectscreening',
            name='subject_identifier',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]
