# Generated by Django 3.1.7 on 2021-04-12 19:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0011_auto_20210225_0604'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalmoccaregistercontact',
            name='icc',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure'), ('N/A', 'Not applicable')], help_text='Either at this facility or elsewhere', max_length=25, null=True, verbose_name='Does the patient currently receive regular integrated care'),
        ),
        migrations.AlterField(
            model_name='moccaregistercontact',
            name='icc',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No'), ('not_sure', 'Not sure'), ('N/A', 'Not applicable')], help_text='Either at this facility or elsewhere', max_length=25, null=True, verbose_name='Does the patient currently receive regular integrated care'),
        ),
    ]
