# Generated by Django 3.1.7 on 2021-04-13 17:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0013_auto_20210413_1942'),
    ]

    operations = [
        migrations.AddField(
            model_name='carestatus',
            name='willing_to_answer',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', max_length=15, verbose_name='Is the patient willing to provide information about their care status?'),
        ),
        migrations.AddField(
            model_name='historicalcarestatus',
            name='willing_to_answer',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', max_length=15, verbose_name='Is the patient willing to provide information about their care status?'),
        ),
    ]
