# Generated by Django 3.1.6 on 2021-02-28 22:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0012_auto_20210301_0054'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='glucosebaseline',
            options={'verbose_name': 'Glucose: Baseline', 'verbose_name_plural': 'Glucose: Baseline'},
        ),
        migrations.AlterModelOptions(
            name='historicalglucosebaseline',
            options={'get_latest_by': 'history_date', 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Glucose: Baseline'},
        ),
        migrations.AlterField(
            model_name='dmreview',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='dmreview',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='glucose',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='glucose',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicaldmreview',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicaldmreview',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalglucose',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
        migrations.AlterField(
            model_name='historicalglucosebaseline',
            name='glucose_fasted',
            field=models.CharField(blank=True, choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Has the participant fasted?'),
        ),
        migrations.AlterField(
            model_name='historicalglucosebaseline',
            name='glucose_units',
            field=models.CharField(blank=True, choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, null=True, verbose_name='Units (glucose)'),
        ),
    ]
