# Generated by Django 3.2.11 on 2022-02-03 22:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0030_auto_20220204_0116'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='arvregimens',
            options={'verbose_name': 'ARV Regimens', 'verbose_name_plural': 'ARV Regimens'},
        ),
    ]
