# Generated by Django 3.2.11 on 2022-02-03 22:16

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_lists', '0005_auto_20210423_1451'),
        ('mocca_subject', '0029_auto_20220131_1925'),
    ]

    operations = [
        migrations.CreateModel(
            name='ArvRegimens',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('mocca_lists.arvregimens',),
        ),
        migrations.AlterField(
            model_name='historicalsubjectvisitmissed',
            name='contact_attempts_count',
            field=models.IntegerField(blank=True, help_text='Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.', null=True, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Number of attempts made to contact participantsince the expected appointment date'),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='contact_attempts_count',
            field=models.IntegerField(blank=True, help_text='Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.', null=True, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Number of attempts made to contact participantsince the expected appointment date'),
        ),
        migrations.AlterField(
            model_name='drugrefillhiv',
            name='rx',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='mocca_subject.arvregimens', verbose_name='Which medicine did the patient receive today?'),
        ),
        migrations.AlterField(
            model_name='historicaldrugrefillhiv',
            name='rx',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.arvregimens', verbose_name='Which medicine did the patient receive today?'),
        ),
    ]
