# Generated by Django 3.1.7 on 2021-04-13 16:42

from django.db import migrations, models
import edc_model.models.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0021_auto_20210331_1728'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalnextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, validators=[edc_model.models.validators.date.date_is_not_now, edc_model.models.validators.date.date_is_future], verbose_name='Next scheduled routine appointment'),
        ),
        migrations.AlterField(
            model_name='nextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, validators=[edc_model.models.validators.date.date_is_not_now, edc_model.models.validators.date.date_is_future], verbose_name='Next scheduled routine appointment'),
        ),
    ]
