DIABETES_CLINIC = "diabetes_clinic"
HIV_CLINIC = "hiv_clinic"
HIV_COHORT = "hiv_cohort"
HYPERTENSION_CLINIC = "hypertension_clinic"
NCD_CLINIC = "ncd_clinic"
NCD_COHORT = "ncd_cohort"
SYSTEMATIC = "systematic"
SEQUENTIAL = "sequential"
NCD = "ncd"
INTEGRATED = "integrated"
NO_INTERRUPTION = "no_interruption"
SOME_INTERRUPTION = "some_interruption"
