# Generated by Django 3.0.9 on 2020-12-06 18:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0020_auto_20201206_2110"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalmoccaregistercontact",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_care",
            new_name="care",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_care_facility_location",
            new_name="care_facility_location",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="not_in_care_reason",
            new_name="care_not_in_reason",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="not_in_icc_reason",
            new_name="icc_not_in_reason",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_icc_since_mocca",
            new_name="icc_since_mocca",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_icc_since_mocca_comment",
            new_name="icc_since_mocca_comment",
        ),
        migrations.RenameField(
            model_name="moccaregistercontact",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_care",
            new_name="care",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_care_facility_location",
            new_name="care_facility_location",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="not_in_care_reason",
            new_name="care_not_in_reason",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="not_in_icc_reason",
            new_name="icc_not_in_reason",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_icc_since_mocca",
            new_name="icc_since_mocca",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_icc_since_mocca_comment",
            new_name="icc_since_mocca_comment",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="comment",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="comment",
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="care_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Additional comments related to this patient's care",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="care_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Additional comments related to this patient's care",
            ),
        ),
    ]
