# Generated by Django 3.0.9 on 2020-12-06 18:10

import edc_model_fields.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0019_auto_20201205_1834"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="death_date",
            field=models.DateField(blank=True, null=True, verbose_name="Date of death"),
        ),
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Additioanl comments"),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_care",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                null=True,
                verbose_name="Is the patient in care?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_care_facility_location",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either integrated or vertical",
                max_length=25,
                null=True,
                verbose_name="Does the patient receive care in this facility",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_icc_since_mocca",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("partially", "Partially"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="Has the patient received regular integrated care since the leaving the MOCCA (orig) trial until now?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_icc_since_mocca_comment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="not_in_care_reason",
            field=models.CharField(
                blank=True,
                max_length=25,
                null=True,
                verbose_name="If not in care, why?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="not_in_icc_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                ],
                max_length=25,
                null=True,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="death_date",
            field=models.DateField(blank=True, null=True, verbose_name="Date of death"),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Additioanl comments"),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_care",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                null=True,
                verbose_name="Is the patient in care?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_care_facility_location",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either integrated or vertical",
                max_length=25,
                null=True,
                verbose_name="Does the patient receive care in this facility",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_icc_since_mocca",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("partially", "Partially"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="Has the patient received regular integrated care since the leaving the MOCCA (orig) trial until now?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_icc_since_mocca_comment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="not_in_care_reason",
            field=models.CharField(
                blank=True,
                max_length=25,
                null=True,
                verbose_name="If not in care, why?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="not_in_icc_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                ],
                max_length=25,
                null=True,
                verbose_name="If not integrated care, why not?",
            ),
        ),
    ]
