# Generated by Django 3.0.9 on 2020-12-14 23:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0001_squashed_0024_auto_20201206_2352"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="-",
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="requires_acute_care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="-",
                max_length=25,
                verbose_name="Does the patient require acute care including in-patient admission",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="_",
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="requires_acute_care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="-",
                max_length=25,
                verbose_name="Does the patient require acute care including in-patient admission",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Is the patient in care?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Is the patient in care?",
            ),
        ),
    ]
