# Generated by Django 3.1.6 on 2021-02-28 21:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0010_auto_20210228_2319'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dminitialreview',
            name='glucose_performed',
        ),
        migrations.RemoveField(
            model_name='historicaldminitialreview',
            name='glucose_performed',
        ),
    ]
