# Generated by Django 3.2.9 on 2022-01-09 14:05

from django.db import migrations, models
import django.db.models.deletion
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0025_alter_bloodresultslipid_requisition'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicalpatienthealth',
            name='ph9_not_performed_reason',
            field=models.TextField(blank=True, max_length=200, null=True, verbose_name='If NO, please provide a reason'),
        ),
        migrations.AddField(
            model_name='historicalpatienthealth',
            name='ph9_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', max_length=15, verbose_name='Is the PH9 assessment being performed?'),
        ),
        migrations.AddField(
            model_name='patienthealth',
            name='ph9_not_performed_reason',
            field=models.TextField(blank=True, max_length=200, null=True, verbose_name='If NO, please provide a reason'),
        ),
        migrations.AddField(
            model_name='patienthealth',
            name='ph9_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='Yes', max_length=15, verbose_name='Is the PH9 assessment being performed?'),
        ),
        migrations.AlterField(
            model_name='cholinitialreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='cholmedicationadherence',
            name='other_missed_pill_reason',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AlterField(
            model_name='cholreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='clinicalreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='clinicalreviewbaseline',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='dminitialreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='dmmedicationadherence',
            name='other_missed_pill_reason',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AlterField(
            model_name='dmreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='historicalcholmedicationadherence',
            name='other_missed_pill_reason',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AlterField(
            model_name='historicaldmmedicationadherence',
            name='other_missed_pill_reason',
            field=edc_model.models.fields.other_charfield.OtherCharField(blank=True, max_length=150, null=True, verbose_name='If other, please specify ...'),
        ),
        migrations.AlterField(
            model_name='historicalnextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, verbose_name='Next scheduled routine appointment'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9appetit',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Poor appetite or over eating'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9badabt',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Feeling bad about yourself or that you are a failure or have let yourself or your family down'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9concen',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Trouble concentrating on things such as reading the newspapers or watching television'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9feel',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Feeling down, depressed or hopeless'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9functio',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='If you checked off any problems on this questionnaire so far, how difficult have these problems made it for you to do your work, take care of things at home or get along with other people?'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9interst',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Little interest or pleasure in doing things'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9moving',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Moving or speaking so slowly  that other people could have noticed or the opposite: being so fidgety or restless that you have been moving around a lot more than usual'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9though',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Thoughts that you would be better off dead or of hurting yourself in some way'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9tired',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Feeling tired or having little energy'),
        ),
        migrations.AlterField(
            model_name='historicalpatienthealth',
            name='ph9troubl',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Trouble falling/staying asleep, sleeping too much'),
        ),
        migrations.AlterField(
            model_name='hivinitialreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='hivreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='htninitialreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='htnreview',
            name='subject_visit',
            field=models.OneToOneField(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectvisit'),
        ),
        migrations.AlterField(
            model_name='nextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, verbose_name='Next scheduled routine appointment'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9appetit',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Poor appetite or over eating'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9badabt',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Feeling bad about yourself or that you are a failure or have let yourself or your family down'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9concen',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Trouble concentrating on things such as reading the newspapers or watching television'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9feel',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Feeling down, depressed or hopeless'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9functio',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='If you checked off any problems on this questionnaire so far, how difficult have these problems made it for you to do your work, take care of things at home or get along with other people?'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9interst',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Little interest or pleasure in doing things'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9moving',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Moving or speaking so slowly  that other people could have noticed or the opposite: being so fidgety or restless that you have been moving around a lot more than usual'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9though',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Thoughts that you would be better off dead or of hurting yourself in some way'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9tired',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Feeling tired or having little energy'),
        ),
        migrations.AlterField(
            model_name='patienthealth',
            name='ph9troubl',
            field=models.CharField(choices=[('not_at_all', 'Not at all'), ('several_days', 'Several days'), ('more_than_half', 'More than half the days'), ('nearly_everyday', 'Nearly everyday'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Trouble falling/staying asleep, sleeping too much'),
        ),
    ]
