# Generated by Django 3.1.7 on 2021-04-13 16:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_screening', '0012_auto_20210412_2237'),
    ]

    operations = [
        migrations.RenameField(
            model_name='historicalmoccaregister',
            old_name='screen_now',
            new_name='subject_present',
        ),
        migrations.RenameField(
            model_name='moccaregister',
            old_name='screen_now',
            new_name='subject_present',
        ),
        migrations.AlterField(
            model_name='historicalsubjectrefusal',
            name='reason',
            field=models.CharField(choices=[('unwilling_to_say', 'Unwilling to give any reason'), ('worried_about_care', 'Worried that he/she will not get the care needed'), ('mixing_and_stigme', 'Does not want to mix with patients with other conditions because of concern around stigma'), ('mixing_and_infection', 'Does not want to mix with patients with other conditions because of concerns around contracting infections'), ('happy_vertical_care', 'Patient is happy with the care being given in vertical clinics'), ('no_participant', 'No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic'), ('receives_community_care', 'Patient is receiving HIV care in the community and does not wish to return to facility-based care'), ('unable_to_contact', 'Clinic was unable to contact the subject'), ('OTHER', 'Other, please specify')], max_length=25, verbose_name='Reason for refusal to join'),
        ),
        migrations.AlterField(
            model_name='historicalsubjectrefusalscreening',
            name='reason',
            field=models.CharField(choices=[('unwilling_to_say', 'Unwilling to give any reason'), ('worried_about_care', 'Worried that he/she will not get the care needed'), ('mixing_and_stigme', 'Does not want to mix with patients with other conditions because of concern around stigma'), ('mixing_and_infection', 'Does not want to mix with patients with other conditions because of concerns around contracting infections'), ('happy_vertical_care', 'Patient is happy with the care being given in vertical clinics'), ('no_participant', 'No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic'), ('receives_community_care', 'Patient is receiving HIV care in the community and does not wish to return to facility-based care'), ('unable_to_contact', 'Clinic was unable to contact the subject'), ('OTHER', 'Other, please specify')], max_length=25, verbose_name='Reason for refusal to screen'),
        ),
        migrations.AlterField(
            model_name='subjectrefusal',
            name='reason',
            field=models.CharField(choices=[('unwilling_to_say', 'Unwilling to give any reason'), ('worried_about_care', 'Worried that he/she will not get the care needed'), ('mixing_and_stigme', 'Does not want to mix with patients with other conditions because of concern around stigma'), ('mixing_and_infection', 'Does not want to mix with patients with other conditions because of concerns around contracting infections'), ('happy_vertical_care', 'Patient is happy with the care being given in vertical clinics'), ('no_participant', 'No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic'), ('receives_community_care', 'Patient is receiving HIV care in the community and does not wish to return to facility-based care'), ('unable_to_contact', 'Clinic was unable to contact the subject'), ('OTHER', 'Other, please specify')], max_length=25, verbose_name='Reason for refusal to join'),
        ),
        migrations.AlterField(
            model_name='subjectrefusalscreening',
            name='reason',
            field=models.CharField(choices=[('unwilling_to_say', 'Unwilling to give any reason'), ('worried_about_care', 'Worried that he/she will not get the care needed'), ('mixing_and_stigme', 'Does not want to mix with patients with other conditions because of concern around stigma'), ('mixing_and_infection', 'Does not want to mix with patients with other conditions because of concerns around contracting infections'), ('happy_vertical_care', 'Patient is happy with the care being given in vertical clinics'), ('no_participant', 'No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic'), ('receives_community_care', 'Patient is receiving HIV care in the community and does not wish to return to facility-based care'), ('unable_to_contact', 'Clinic was unable to contact the subject'), ('OTHER', 'Other, please specify')], max_length=25, verbose_name='Reason for refusal to screen'),
        ),
    ]
