# Generated by Django 3.2.10 on 2021-12-09 17:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_ae', '0004_auto_20210428_0005'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aefollowup',
            name='tracking_identifier',
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name='aeinitial',
            name='tracking_identifier',
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name='aesusar',
            name='tracking_identifier',
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name='aetmg',
            name='tracking_identifier',
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name='deathreport',
            name='tracking_identifier',
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name='deathreporttmg',
            name='tracking_identifier',
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name='historicalaefollowup',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name='historicalaeinitial',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name='historicalaesusar',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name='historicalaetmg',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name='historicaldeathreport',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name='historicaldeathreporttmg',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name='historicaldeathreporttmgsecond',
            name='tracking_identifier',
            field=models.CharField(db_index=True, max_length=32),
        ),
    ]
