# Generated by Django 3.2.11 on 2022-01-31 16:25

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0028_auto_20220109_1722'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalsubjectvisitmissed',
            name='contact_attempts_count',
            field=models.IntegerField(blank=True, help_text='Not including pre-appointment reminders', null=True, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Number of attempts made to contact participantsince the expected appointment date'),
        ),
        migrations.AlterField(
            model_name='subjectvisitmissed',
            name='contact_attempts_count',
            field=models.IntegerField(blank=True, help_text='Not including pre-appointment reminders', null=True, validators=[django.core.validators.MinValueValidator(1)], verbose_name='Number of attempts made to contact participantsince the expected appointment date'),
        ),
    ]
