# Generated by Django 3.2.9 on 2021-12-11 15:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0024_auto_20211211_1856'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bloodresultslipid',
            name='requisition',
            field=models.ForeignKey(blank=True, help_text='Start typing the requisition identifier or select one from this visit', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='mocca_subject.subjectrequisition', verbose_name='Requisition'),
        ),
    ]
