# Generated by Django 3.1.5 on 2021-01-31 17:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_subject", "0007_auto_20210115_0423"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="info_source",
            field=models.CharField(
                choices=[
                    ("patient", "Patient"),
                    ("patient_representative", "Patient Representative"),
                    (
                        "patient_and_outpatient",
                        "Patient, hospital notes and/or outpatient card",
                    ),
                    ("collateral_history", "Collateral History from relative/guardian"),
                    ("hospital_notes", "Hospital notes"),
                    ("outpatient_cards", "Outpatient cards"),
                    ("N/A", "Not applicable"),
                    ("OTHER", "Other"),
                ],
                max_length=25,
                verbose_name="What is the main source of this information?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="info_source",
            field=models.CharField(
                choices=[
                    ("patient", "Patient"),
                    ("patient_representative", "Patient Representative"),
                    (
                        "patient_and_outpatient",
                        "Patient, hospital notes and/or outpatient card",
                    ),
                    ("collateral_history", "Collateral History from relative/guardian"),
                    ("hospital_notes", "Hospital notes"),
                    ("outpatient_cards", "Outpatient cards"),
                    ("N/A", "Not applicable"),
                    ("OTHER", "Other"),
                ],
                max_length=25,
                verbose_name="What is the main source of this information?",
            ),
        ),
    ]
