DIET_LIFESTYLE = "diet_lifestyle"
DRUGS = "drugs"
GTE_3HRS = "gte_3hr"
HIV = "hiv"  # TODO: reconcile with edc_constants.HIV
INSULIN = "insulin"
INTEGRATED = "integrated"
NCD = "ncd"
SITTING = "sitting"
THIS_CLINIC = "this_clinic"
VERTICAL = "vertical"
