# Generated by Django 3.0.9 on 2020-12-16 01:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0007_auto_20201215_1552"),
    ]

    operations = [
        migrations.AlterField(
            model_name="carestatus",
            name="icc_not_in_reason",
            field=models.CharField(
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                    (
                        "receives_community_care",
                        "Patient is currently receiving their HIV care in the community",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcarestatus",
            name="icc_not_in_reason",
            field=models.CharField(
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                    (
                        "receives_community_care",
                        "Patient is currently receiving their HIV care in the community",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="reason",
            field=models.CharField(
                choices=[
                    ("unwilling_to_say", "Unwilling to give any reason"),
                    (
                        "worried_about_care",
                        "Worried that he/she will not get the care needed",
                    ),
                    (
                        "mixing_and_stigme",
                        "Does not want to mix with patients with other conditions because of concern around stigma",
                    ),
                    (
                        "mixing_and_infection",
                        "Does not want to mix with patients with other conditions because of concerns around contracting infections",
                    ),
                    (
                        "happy_vertical_care",
                        "Patient is happy with the care being given in vertical clinics",
                    ),
                    (
                        "no_participant",
                        "No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic",
                    ),
                    (
                        "receives_community_care",
                        "Patient is receiving HIV care in the community and does not wish to return to facility-based care",
                    ),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="Reason for refusal to join",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusalscreening",
            name="reason",
            field=models.CharField(
                choices=[
                    ("unwilling_to_say", "Unwilling to give any reason"),
                    (
                        "worried_about_care",
                        "Worried that he/she will not get the care needed",
                    ),
                    (
                        "mixing_and_stigme",
                        "Does not want to mix with patients with other conditions because of concern around stigma",
                    ),
                    (
                        "mixing_and_infection",
                        "Does not want to mix with patients with other conditions because of concerns around contracting infections",
                    ),
                    (
                        "happy_vertical_care",
                        "Patient is happy with the care being given in vertical clinics",
                    ),
                    (
                        "no_participant",
                        "No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic",
                    ),
                    (
                        "receives_community_care",
                        "Patient is receiving HIV care in the community and does not wish to return to facility-based care",
                    ),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="Reason for refusal to screen",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="icc_not_in_reason",
            field=models.CharField(
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                    (
                        "receives_community_care",
                        "Patient is currently receiving their HIV care in the community",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="reason",
            field=models.CharField(
                choices=[
                    ("unwilling_to_say", "Unwilling to give any reason"),
                    (
                        "worried_about_care",
                        "Worried that he/she will not get the care needed",
                    ),
                    (
                        "mixing_and_stigme",
                        "Does not want to mix with patients with other conditions because of concern around stigma",
                    ),
                    (
                        "mixing_and_infection",
                        "Does not want to mix with patients with other conditions because of concerns around contracting infections",
                    ),
                    (
                        "happy_vertical_care",
                        "Patient is happy with the care being given in vertical clinics",
                    ),
                    (
                        "no_participant",
                        "No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic",
                    ),
                    (
                        "receives_community_care",
                        "Patient is receiving HIV care in the community and does not wish to return to facility-based care",
                    ),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="Reason for refusal to join",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusalscreening",
            name="reason",
            field=models.CharField(
                choices=[
                    ("unwilling_to_say", "Unwilling to give any reason"),
                    (
                        "worried_about_care",
                        "Worried that he/she will not get the care needed",
                    ),
                    (
                        "mixing_and_stigme",
                        "Does not want to mix with patients with other conditions because of concern around stigma",
                    ),
                    (
                        "mixing_and_infection",
                        "Does not want to mix with patients with other conditions because of concerns around contracting infections",
                    ),
                    (
                        "happy_vertical_care",
                        "Patient is happy with the care being given in vertical clinics",
                    ),
                    (
                        "no_participant",
                        "No longer wishes to be a study participant but is happy to continue receiving care in the integrated clinic",
                    ),
                    (
                        "receives_community_care",
                        "Patient is receiving HIV care in the community and does not wish to return to facility-based care",
                    ),
                    ("OTHER", "Other, please specify"),
                ],
                max_length=25,
                verbose_name="Reason for refusal to screen",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="icc_not_in_reason",
            field=models.CharField(
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                    (
                        "receives_community_care",
                        "Patient is currently receiving their HIV care in the community",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If not integrated care, why not?",
            ),
        ),
    ]
