# Generated by Django 3.0.9 on 2020-12-15 03:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0004_auto_20201215_0602"),
    ]

    operations = [
        migrations.AlterField(
            model_name="carestatus",
            name="icc",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Either at this facility or elsewhere",
                max_length=25,
                verbose_name="Does the patient currently receive integrated care",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="icc",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Either at this facility or elsewhere",
                max_length=25,
                verbose_name="Does the patient currently receive integrated care",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="icc",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Either at this facility or elsewhere",
                max_length=25,
                verbose_name="Does the patient currently receive integrated care",
            ),
        ),
    ]
