# Generated by Django 3.2.9 on 2021-12-11 15:56

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0023_auto_20211211_1852'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bloodresultslipid',
            name='chol_value',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0.0), django.core.validators.MaxValueValidator(999.0)], verbose_name='Total Cholesterol'),
        ),
        migrations.AlterField(
            model_name='historicalbloodresultslipid',
            name='chol_value',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, validators=[django.core.validators.MinValueValidator(0.0), django.core.validators.MaxValueValidator(999.0)], verbose_name='Total Cholesterol'),
        ),
    ]
