# Generated by Django 3.2.9 on 2022-01-09 14:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0027_auto_20220109_1717'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='glucose',
            name='assay_datetime',
        ),
        migrations.RemoveField(
            model_name='glucose',
            name='requisition',
        ),
        migrations.RemoveField(
            model_name='historicalglucose',
            name='assay_datetime',
        ),
        migrations.RemoveField(
            model_name='historicalglucose',
            name='requisition',
        ),
        migrations.RemoveField(
            model_name='historicalglucosebaseline',
            name='assay_datetime',
        ),
        migrations.RemoveField(
            model_name='historicalglucosebaseline',
            name='requisition',
        ),
    ]
