# Generated by Django 3.0.9 on 2021-01-15 01:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_subject", "0005_auto_20210114_2257"),
    ]

    operations = [
        migrations.AddField(
            model_name="dminitialreview",
            name="dx_location",
            field=models.CharField(
                choices=[
                    ("hospital", "Hospital"),
                    ("gov_clinic", "Government clinic"),
                    ("private_clinic", "Private clinic"),
                    ("private_doctor", "Private doctor"),
                    ("mocca_clinic", "MOCCA study clinic"),
                ],
                default="mocca_clinic",
                max_length=25,
                verbose_name="Was the diagnosis date estimated?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicaldminitialreview",
            name="dx_location",
            field=models.CharField(
                choices=[
                    ("hospital", "Hospital"),
                    ("gov_clinic", "Government clinic"),
                    ("private_clinic", "Private clinic"),
                    ("private_doctor", "Private doctor"),
                    ("mocca_clinic", "MOCCA study clinic"),
                ],
                default="mocca_clinic",
                max_length=25,
                verbose_name="Was the diagnosis date estimated?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhivinitialreview",
            name="dx_location",
            field=models.CharField(
                choices=[
                    ("hospital", "Hospital"),
                    ("gov_clinic", "Government clinic"),
                    ("private_clinic", "Private clinic"),
                    ("private_doctor", "Private doctor"),
                    ("mocca_clinic", "MOCCA study clinic"),
                ],
                default="mocca_clinic",
                max_length=25,
                verbose_name="Was the diagnosis date estimated?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="dx_location",
            field=models.CharField(
                choices=[
                    ("hospital", "Hospital"),
                    ("gov_clinic", "Government clinic"),
                    ("private_clinic", "Private clinic"),
                    ("private_doctor", "Private doctor"),
                    ("mocca_clinic", "MOCCA study clinic"),
                ],
                default="mocca_clinic",
                max_length=25,
                verbose_name="Was the diagnosis date estimated?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="hivinitialreview",
            name="dx_location",
            field=models.CharField(
                choices=[
                    ("hospital", "Hospital"),
                    ("gov_clinic", "Government clinic"),
                    ("private_clinic", "Private clinic"),
                    ("private_doctor", "Private doctor"),
                    ("mocca_clinic", "MOCCA study clinic"),
                ],
                default="mocca_clinic",
                max_length=25,
                verbose_name="Was the diagnosis date estimated?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="dx_location",
            field=models.CharField(
                choices=[
                    ("hospital", "Hospital"),
                    ("gov_clinic", "Government clinic"),
                    ("private_clinic", "Private clinic"),
                    ("private_doctor", "Private doctor"),
                    ("mocca_clinic", "MOCCA study clinic"),
                ],
                default="mocca_clinic",
                max_length=25,
                verbose_name="Was the diagnosis date estimated?",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason",
            field=models.CharField(
                choices=[
                    ("scheduled", "Scheduled visit (study)"),
                    ("unscheduled", "Routine or unscheduled visit"),
                    ("missed", "Missed visit"),
                ],
                help_text="Only baseline (0m), 6m and 12m are considered `scheduled` visits as per the MOCCA protocol.If `missed' complete CRF Missed Visit Report.",
                max_length=25,
                verbose_name="What is the reason for this visit report?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_unscheduled",
            field=models.CharField(
                choices=[
                    ("routine_non_study", "Routine scheduled (non-study)"),
                    ("patient_unwell_outpatient", "Patient unwell / unscheduled"),
                    ("drug_refill", "Drug refill only"),
                    ("OTHER", "Other"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If 'unscheduled', provide reason for the unscheduled visit",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="reason",
            field=models.CharField(
                choices=[
                    ("scheduled", "Scheduled visit (study)"),
                    ("unscheduled", "Routine or unscheduled visit"),
                    ("missed", "Missed visit"),
                ],
                help_text="Only baseline (0m), 6m and 12m are considered `scheduled` visits as per the MOCCA protocol.If `missed' complete CRF Missed Visit Report.",
                max_length=25,
                verbose_name="What is the reason for this visit report?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="reason_unscheduled",
            field=models.CharField(
                choices=[
                    ("routine_non_study", "Routine scheduled (non-study)"),
                    ("patient_unwell_outpatient", "Patient unwell / unscheduled"),
                    ("drug_refill", "Drug refill only"),
                    ("OTHER", "Other"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If 'unscheduled', provide reason for the unscheduled visit",
            ),
        ),
    ]
