# Generated by Django 3.0.9 on 2020-12-05 15:34

import django_crypto_fields.fields.encrypted_text_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0018_auto_20201205_0424"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregister",
            name="next_appt_date",
            field=models.DateField(
                blank=True, help_text="auto-updated", null=True, verbose_name="Appt"
            ),
        ),
        migrations.AddField(
            model_name="moccaregister",
            name="next_appt_date",
            field=models.DateField(
                blank=True, help_text="auto-updated", null=True, verbose_name="Appt"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregister",
            name="contact_attempts",
            field=models.IntegerField(default=0, help_text="auto-updated"),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregister",
            name="date_last_called",
            field=models.DateField(help_text="auto-updated", null=True),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregister",
            name="notes",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=71,
                null=True,
                verbose_name="General notes",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregistercontact",
            name="comment",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=71,
                null=True,
                verbose_name="Note",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregistercontact",
            name="next_appt_date",
            field=models.DateField(blank=True, null=True, verbose_name="Next Appt."),
        ),
        migrations.AlterField(
            model_name="moccaregister",
            name="contact_attempts",
            field=models.IntegerField(default=0, help_text="auto-updated"),
        ),
        migrations.AlterField(
            model_name="moccaregister",
            name="date_last_called",
            field=models.DateField(help_text="auto-updated", null=True),
        ),
        migrations.AlterField(
            model_name="moccaregister",
            name="notes",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=71,
                null=True,
                verbose_name="General notes",
            ),
        ),
        migrations.AlterField(
            model_name="moccaregistercontact",
            name="comment",
            field=django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                blank=True,
                help_text=" (Encryption: AES local)",
                max_length=71,
                null=True,
                verbose_name="Note",
            ),
        ),
        migrations.AlterField(
            model_name="moccaregistercontact",
            name="next_appt_date",
            field=models.DateField(blank=True, null=True, verbose_name="Next Appt."),
        ),
    ]
