model_data = {
    "edc_lab.consignee": [
        {
            "name": "The MOCCA Trial",
            "contact_name": "Josphine Birungi",
            "address": "LSTM Uganda",
            "postal_code": "-",
            "city": "Entebbe",
            "state": None,
            "country": "Uganda",
            "telephone": "555-5555",
            "mobile": "555-5555",
            "fax": None,
            "email": "josephine.birungi@mrcuganda.org",
        }
    ]
}

unique_field_data = {"edc_lab.consignee": {"name": ("-", "-")}}
