# Generated by Django 3.0.9 on 2020-12-04 20:47

import django_crypto_fields.fields.encrypted_char_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0015_auto_20201204_2339"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="comment",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Note",
            ),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="comment",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Note",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregister",
            name="best_tel",
            field=models.CharField(
                blank=True,
                choices=[
                    ("tel_1", "Tel/Mobile(1)"),
                    ("tel_2", "Tel/Mobile(2)"),
                    ("tel_3", "Tel/Mobile(3)"),
                ],
                help_text="If any, select the best telephone/mobile from above",
                max_length=15,
                null=True,
                verbose_name="Prefered Telephone / Mobile",
            ),
        ),
        migrations.AlterField(
            model_name="moccaregister",
            name="best_tel",
            field=models.CharField(
                blank=True,
                choices=[
                    ("tel_1", "Tel/Mobile(1)"),
                    ("tel_2", "Tel/Mobile(2)"),
                    ("tel_3", "Tel/Mobile(3)"),
                ],
                help_text="If any, select the best telephone/mobile from above",
                max_length=15,
                null=True,
                verbose_name="Prefered Telephone / Mobile",
            ),
        ),
    ]
