# Generated by Django 3.2.10 on 2021-12-09 17:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_prn", "0002_auto_20210225_0604"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="requestor",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingrequest",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="reviewer",
        ),
        migrations.RemoveField(
            model_name="historicalunblindingreview",
            name="site",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="requestor",
        ),
        migrations.RemoveField(
            model_name="unblindingrequest",
            name="site",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="reviewer",
        ),
        migrations.RemoveField(
            model_name="unblindingreview",
            name="site",
        ),
        migrations.DeleteModel(
            name="UnblindingRequestorUser",
        ),
        migrations.DeleteModel(
            name="UnblindingReviewerUser",
        ),
        migrations.RenameField(
            model_name="historicallosstofollowup",
            old_name="loss_category_other",
            new_name="ltfu_category_other",
        ),
        migrations.RenameField(
            model_name="losstofollowup",
            old_name="loss_category_other",
            new_name="ltfu_category_other",
        ),
        migrations.RenameField(
            model_name="historicallosstofollowup",
            old_name="loss_category",
            new_name="ltfu_category",
        ),
        migrations.RenameField(
            model_name="losstofollowup",
            old_name="loss_category",
            new_name="ltfu_category",
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicaloffschedule",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicalprotocoldeviationviolation",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="protocoldeviationviolation",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.DeleteModel(
            name="HistoricalUnblindingRequest",
        ),
        migrations.DeleteModel(
            name="HistoricalUnblindingReview",
        ),
        migrations.DeleteModel(
            name="UnblindingRequest",
        ),
        migrations.DeleteModel(
            name="UnblindingReview",
        ),
    ]
