# Generated by Django 3.2.11 on 2022-02-03 23:25

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_lists", "0005_auto_20210423_1451"),
        ("mocca_subject", "0031_alter_arvregimens_options"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="ArvRegimens",
            new_name="Rx",
        ),
        migrations.AlterField(
            model_name="drugrefillhiv",
            name="rx",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="mocca_subject.rx",
                verbose_name="Which medicine did the patient receive today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="rx",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="mocca_subject.rx",
                verbose_name="Which medicine did the patient receive today?",
            ),
        ),
    ]
