# Generated by Django 3.1.6 on 2021-02-25 03:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('edc_action_item', '0028_auto_20210203_0706'),
        ('mocca_ae', '0002_auto_20210129_0556'),
    ]

    operations = [
        migrations.AlterField(
            model_name='aefollowup',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aefollowup',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aefollowup',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aefollowup',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aefollowup',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aeinitial',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aeinitial',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aeinitial',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aeinitial',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aeinitial',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aesusar',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aesusar',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aesusar',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aesusar',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aesusar',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aetmg',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aetmg',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aetmg',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='aetmg',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='aetmg',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='deathreport',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='deathreport',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='deathreport',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='deathreport',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='deathreport',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='deathreporttmg',
            name='action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='deathreporttmg',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='deathreporttmg',
            name='parent_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='deathreporttmg',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='deathreporttmg',
            name='related_action_item',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='+', to='edc_action_item.actionitem'),
        ),
        migrations.AlterField(
            model_name='historicalaefollowup',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaefollowup',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaeinitial',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaeinitial',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaesusar',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaesusar',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaetmg',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicalaetmg',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldeathreport',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldeathreport',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldeathreporttmg',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldeathreporttmg',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldeathreporttmgsecond',
            name='parent_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to parent reference model instance.', max_length=30, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldeathreporttmgsecond',
            name='related_action_identifier',
            field=models.CharField(blank=True, help_text='action identifier that links to related reference model instance.', max_length=30, null=True),
        ),
    ]
