<a id="subjectscreening_change_{{ screening_identifier }}" title="{{ title }}" role="button" 
   class="btn btn-sm btn-{% if eligible == YES %}success{% elif eligible == TBD %}warning{% else %}default{% endif %}"
   href="{{ href }}">
    <i class="fas fa-pencil-alt fa-sm"></i> 
</a>