# Generated by Django 3.0.9 on 2020-12-04 00:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0007_auto_20201204_0232"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalmoccaregistercontact",
            old_name="contacted",
            new_name="answered",
        ),
        migrations.RenameField(
            model_name="moccaregistercontact",
            old_name="contacted",
            new_name="answered",
        ),
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="respondent",
            field=models.CharField(
                choices=[
                    ("patient", "Patient"),
                    ("family", "Family"),
                    ("friend", "friend"),
                    ("other", "other"),
                ],
                default="No",
                max_length=15,
            ),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="respondent",
            field=models.CharField(
                choices=[
                    ("patient", "Patient"),
                    ("family", "Family"),
                    ("friend", "friend"),
                    ("other", "other"),
                ],
                default="No",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregistercontact",
            name="call_again",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Try again?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregistercontact",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                ],
                default="unknown",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="historicalmoccaregistercontact",
            name="willing_to_attend",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                default="unknown",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="moccaregistercontact",
            name="call_again",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Try again?",
            ),
        ),
        migrations.AlterField(
            model_name="moccaregistercontact",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                ],
                default="unknown",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="moccaregistercontact",
            name="willing_to_attend",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                default="unknown",
                max_length=15,
            ),
        ),
    ]
